Name:           emilua
Version:        0.11.5
Release:        %autorelease
Summary:        Lua execution engine
License:        BSL-1.0 AND MIT
URL:            https://gitlab.com/%{name}/%{name}

# The primary source for Emilua
Source0:        %{url}/-/archive/v%{version}/%{name}-v%{version}.tar.gz

BuildRequires:  meson
BuildRequires:  gcc-c++
BuildRequires:  boost-devel
BuildRequires:  cereal-devel
BuildRequires:  re2c
BuildRequires:  gawk
BuildRequires:  gperf
BuildRequires:  rubygem-asciidoctor
BuildRequires:  pkgconfig
BuildRequires:  luajit-devel
BuildRequires:  fmt-devel
BuildRequires:  cmake
BuildRequires:  liburing-devel
BuildRequires:  libcap-devel >= 2.69
BuildRequires:  openssl-devel
BuildRequires:  ncurses-devel
BuildRequires:  serd-devel
BuildRequires:  sord-devel
%if 0%{?fedora} >= 41
BuildRequires: openssl-devel-engine
%endif

# Disable generation of .build-id links
%global _build_id_links none

%description
Emilua is a cross-platform Lua execution engine with support for asynchronous I/O and flexible threading.
It implements many concurrency models for applications to experiment with, including fiber, actors, and process-based concurrency.
For process-based concurrency, it also offers many sandboxing choices.

%package devel
Summary: Development files for emilua
Requires: %{name} = %{version}-%{release}

%description devel
Development files (Headers, etc) for emilua.

%prep
%autosetup -n %{name}-v%{version}

%build
%meson -Dversion_suffix=-fedora%{release} -Denable_file_io=true -Denable_io_uring=true
%meson_build

%check
%ifarch i386 i486 i586 i686
# Note: This only affects very specific use cases (e.g., overriding Glibc
# functions for sandbox experimentation). The bug is not a security issue
# - it fails when adding permissions, not when removing them.
# The build still works fine; only this niche sandboxing feature (for advanced
# tinkering) is impacted. The bug has already been reported: 
# https://gitlab.com/emilua/emilua/-/issues/167
    meson test -C %{_vpath_builddir} --no-suite libc_service ||:
%else
    %meson_test
%endif

%install
%meson_install

%files
%{_bindir}/%{name}
%{_libdir}/libemilua-preload-libc.so.0.11.5
%{_libdir}/libemilua-preload-libc.so.0
%{_libdir}/libemilua-preload-libc.so
%{_libdir}/libemilua-main.so.0.11.5
%{_libdir}/libemilua-main.so.0
%{_libdir}/libemilua-main.so
%{_libdir}/libemilua-libc-service.so.0.11.5
%{_libdir}/libemilua-libc-service.so.0
%{_libdir}/libemilua-libc-service.so
%{_libdir}/libemilua.so.0.11.5
%{_libdir}/libemilua.so.0
%{_libdir}/libemilua.so
%{_mandir}/man1/*
%dir %{_mandir}/man3em
%{_mandir}/man3em/*
%{_mandir}/man7/*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*
%{_libdir}/libemilua.so
%{_libdir}/pkgconfig/%{name}*.pc
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/*

%changelog
%autochangelog
* Tue Apr 22 2025 Valter Nazianzeno <manipuladordedados@gmail.com> - 0.11.5-1
